package com.bipt.intelligentapplicationorchestrationservice.controller;

import com.bipt.intelligentapplicationorchestrationservice.constant.MessageConstant;
import com.bipt.intelligentapplicationorchestrationservice.pojo.OptResult;
import com.bipt.intelligentapplicationorchestrationservice.util.AliOssUtil;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.UUID;

@Slf4j
@RestController
@RequestMapping("/common")
@Tag(name = "通用接口")
@CrossOrigin(origins = "http://localhost:3000")
public class CommonController {
    @Autowired
    private AliOssUtil aliOssUtil;
    // 默认上传的文件夹
    private static final String DEFAULT_FOLDER= "File/";

    /**
     * 文件上传
     * @param file
     * @return
     */
    @Operation(summary = "文件上传")
    @PostMapping("/upload")
    public OptResult uploadFile(@RequestParam("file") MultipartFile file) throws IOException {
        log.info("收到上传请求");
        if (file.isEmpty()){
            return OptResult.error(MessageConstant.FILE_EMPTY);
        }
        try  {
            // 1.生成唯一文件名
            String originalFilename = file.getOriginalFilename();   //  原始文件名
            log.info("原始文件名:{}", originalFilename);
            String fileSuffix = originalFilename.substring(originalFilename.lastIndexOf("."));  // 文件后缀
            log.info("文件后缀:{}", fileSuffix);
            String fileName = UUID.randomUUID().toString() + fileSuffix; // 唯一文件名
            log.info("唯一文件名:{}", fileName);
            // 2.构建oss存储路径
            String objectName = DEFAULT_FOLDER + fileName;
            // 3.调用工具类上传文件
            String fileUrl = aliOssUtil.upload(file.getInputStream(), objectName);
            // 4.返回文件URL
            return OptResult.success(fileUrl);
        } catch (Exception e) {
            log.error(MessageConstant.UPLOAD_FAILURE +":{}", e.getMessage(), e);
            return OptResult.error(MessageConstant.UPLOAD_FAILURE);
        }

    }
}
